@@ -1,6 +1,6 @@
 package HTTP::Body;
 BEGIN {
-  $HTTP::Body::VERSION = '1.09';
+  $HTTP::Body::VERSION = '1.10';
 }
 
 use strict;
@@ -393,6 +393,20 @@ sub tmpdir {
 
 =back
 
+=head1 SUPPORT
+
+Since its original creation this module has been taken over by the Catalyst
+development team. If you want to contribute patches, these will be your
+primary contact points:
+
+IRC:
+
+    Join #catalyst-dev on irc.perl.org.
+
+Mailing Lists:
+
+    http://lists.scsys.co.uk/cgi-bin/mailman/listinfo/catalyst-dev
+
 =head1 AUTHOR
 
 Christian Hansen, C<chansen@cpan.org>
@@ -401,6 +415,14 @@ Sebastian Riedel, C<sri@cpan.org>
 
 Andy Grundman, C<andy@hybridized.org>
 
+=head1 CONTRIBUTORS
+
+Simon Elliott C<cpan@papercreatures.com>
+
+Kent Fredric <kentnl@cpan.org>
+
+Christian Walde
+
 =head1 LICENSE
 
 This library is free software. You can redistribute it and/or modify 
